Documentation
¶
Overview ¶
Package github implements AnswerHub provider
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Provider ¶
type Provider struct {
// contains filtered or unexported fields
}
Provider represents the provider
type SRIRepository ¶ added in v1.8.0
type SRIRepository struct {
Fullname string `json:"full_name"`
Description string `json:"description"`
}
SRIRepository represent the structure of the search result items repository
type SRITMatches ¶ added in v1.8.0
type SRITMatches struct {
Fragment string `json:"fragment"`
}
SRITMatches represent the structure of the search result items text matches field
type SRItems ¶ added in v1.8.0
type SRItems struct {
Name string `json:"name"`
Path string `json:"path"`
HTMLUrl string `json:"html_url"`
Repository *SRIRepository `json:"repository"`
TextMatches []*SRITMatches `json:"text_matches"`
}
SRItems represent the structure of the search result items
type SearchResult ¶
type SearchResult struct {
TotalCount int `json:"total_count"`
IncompleteResults bool `json:"incomplete_results"`
Items []*SRItems `json:"items"`
}
SearchResult represent the structure of the search result
Click to show internal directories.
Click to hide internal directories.