Documentation
¶
Overview ¶
Package slack implements Slack provider
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Provider ¶
type Provider struct {
// contains filtered or unexported fields
}
Provider represents the provider
type SearchResult ¶
type SearchResult struct {
Ok bool `json:"ok"`
Query string `json:"query"`
Messages *SearchResultMessages
}
SearchResult represent the structure of the search result
type SearchResultMessages ¶
type SearchResultMessages struct {
Total int `json:"total"`
Path string `json:"path"`
Matches []*SearchResultMessagesMatches `json:"matches"`
}
SearchResultMessages represent the structure of the search result messages
type SearchResultMessagesMatches ¶
type SearchResultMessagesMatches struct {
Type string `json:"type"`
Username string `json:"username"`
Text string `json:"text"`
Permalink string `json:"permalink"`
Channel *SearchResultMessagesMatchesChannel `json:"channel"`
}
SearchResultMessagesMatches represent the structure of the search result messages matches
type SearchResultMessagesMatchesChannel ¶ added in v1.7.0
type SearchResultMessagesMatchesChannel struct {
Name string `json:"name"`
}
SearchResultMessagesMatchesChannel represent the structure of the search result messages matches channel field
Click to show internal directories.
Click to hide internal directories.